@@ -3,6 +3,8 @@
 pub use self::{flow::FlowStat, mon_socket::MonProxySocket, mon_stream::MonProxyStream};
 
 pub mod flow;
+#[cfg(target_os = "macos")]
+pub mod launch_activate_socket;
 pub mod mon_socket;
 pub mod mon_stream;
 pub mod packet_window;
