@@ -10,7 +10,7 @@ use std::{
     time::{Duration, Instant},
 };
 
-use clap::{builder::PossibleValuesParser, Arg, ArgAction, ArgGroup, ArgMatches, Command, ValueHint};
+use clap::{Arg, ArgAction, ArgGroup, ArgMatches, Command, ValueHint, builder::PossibleValuesParser};
 use futures::future::{self, FutureExt};
 use log::{error, info, trace};
 use tokio::{
@@ -25,13 +25,13 @@ use shadowsocks_service::shadowsocks::relay::socks5::Address;
 use shadowsocks_service::{
     acl::AccessControl,
     config::{
-        read_variable_field_value, Config, ConfigType, LocalConfig, LocalInstanceConfig, ProtocolType,
-        ServerInstanceConfig,
+        Config, ConfigType, LocalConfig, LocalInstanceConfig, ProtocolType, ServerInstanceConfig,
+        read_variable_field_value,
     },
-    local::{loadbalancing::PingBalancer, Server},
+    local::{Server, loadbalancing::PingBalancer},
     shadowsocks::{
         config::{Mode, ServerAddr, ServerConfig, ServerSource},
-        crypto::{available_ciphers, CipherKind},
+        crypto::{CipherKind, available_ciphers},
         plugin::PluginConfig,
     },
 };
@@ -40,6 +40,7 @@ use shadowsocks_service::{
 use crate::logging;
 use crate::{
     config::{Config as ServiceConfig, RuntimeMode},
+    error::{ShadowsocksError, ShadowsocksResult},
     monitor, vparser,
 };
 
@@ -576,7 +577,7 @@ pub fn define_command_line_options(mut app: Command) -> Command {
 }
 
 /// Create `Runtime` and `main` entry
-pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = ExitCode>), ExitCode> {
+pub fn create(matches: &ArgMatches) -> ShadowsocksResult<(Runtime, impl Future<Output = ShadowsocksResult> + use<>)> {
     #[cfg_attr(not(feature = "local-online-config"), allow(unused_mut))]
     let (config, _, runtime) = {
         let config_path_opt = matches.get_one::<PathBuf>("CONFIG").cloned().or_else(|| {
@@ -594,13 +595,8 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
         });
 
         let mut service_config = match config_path_opt {
-            Some(ref config_path) => match ServiceConfig::load_from_file(config_path) {
-                Ok(c) => c,
-                Err(err) => {
-                    eprintln!("loading config {config_path:?}, {err}");
-                    return Err(crate::EXIT_CODE_LOAD_CONFIG_FAILURE.into());
-                }
-            },
+            Some(ref config_path) => ServiceConfig::load_from_file(config_path)
+                .map_err(|err| ShadowsocksError::LoadConfigFailure(format!("loading config {config_path:?}, {err}")))?,
             None => ServiceConfig::default(),
         };
         service_config.set_options(matches);
@@ -618,13 +614,8 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
         trace!("{:?}", service_config);
 
         let mut config = match config_path_opt {
-            Some(cpath) => match Config::load_from_file(&cpath, ConfigType::Local) {
-                Ok(cfg) => cfg,
-                Err(err) => {
-                    eprintln!("loading config {cpath:?}, {err}");
-                    return Err(crate::EXIT_CODE_LOAD_CONFIG_FAILURE.into());
-                }
-            },
+            Some(cpath) => Config::load_from_file(&cpath, ConfigType::Local)
+                .map_err(|err| ShadowsocksError::LoadConfigFailure(format!("loading config {cpath:?}, {err}")))?,
             None => Config::new(ConfigType::Local),
         };
 
@@ -892,13 +883,8 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
         }
 
         if let Some(acl_file) = matches.get_one::<String>("ACL") {
-            let acl = match AccessControl::load_from_file(acl_file) {
-                Ok(acl) => acl,
-                Err(err) => {
-                    eprintln!("loading ACL \"{acl_file}\", {err}");
-                    return Err(crate::EXIT_CODE_LOAD_ACL_FAILURE.into());
-                }
-            };
+            let acl = AccessControl::load_from_file(acl_file)
+                .map_err(|err| ShadowsocksError::LoadAclFailure(format!("loading ACL \"{acl_file}\", {err}")))?;
             config.acl = Some(acl);
         }
 
@@ -953,17 +939,16 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
         // DONE READING options
 
         if config.local.is_empty() {
-            eprintln!(
+            return Err(ShadowsocksError::InsufficientParams(
                 "missing `local_address`, consider specifying it by --local-addr command line option, \
                     or \"local_address\" and \"local_port\" in configuration file"
-            );
-            return Err(crate::EXIT_CODE_INSUFFICIENT_PARAMS.into());
+                    .to_string(),
+            ));
         }
 
-        if let Err(err) = config.check_integrity() {
-            eprintln!("config integrity check failed, {err}");
-            return Err(crate::EXIT_CODE_LOAD_CONFIG_FAILURE.into());
-        }
+        config
+            .check_integrity()
+            .map_err(|err| ShadowsocksError::LoadConfigFailure(format!("config integrity check failed, {err}")))?;
 
         #[cfg(unix)]
         if matches.get_flag("DAEMONIZE") || matches.get_raw("DAEMONIZE_PID_PATH").is_some() {
@@ -973,10 +958,9 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
 
         #[cfg(unix)]
         if let Some(uname) = matches.get_one::<String>("USER") {
-            if let Err(err) = crate::sys::run_as_user(uname) {
-                eprintln!("failed to change as user, error: {err}");
-                return Err(crate::EXIT_CODE_INSUFFICIENT_PARAMS.into());
-            }
+            crate::sys::run_as_user(uname).map_err(|err| {
+                ShadowsocksError::InsufficientParams(format!("failed to change as user, error: {err}"))
+            })?;
         }
 
         info!("shadowsocks local {} build {}", crate::VERSION, crate::BUILD_TIME);
@@ -1031,19 +1015,17 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
                     match server_res {
                         // Server future resolved without an error. This should never happen.
                         Ok(..) => {
-                            eprintln!("server exited unexpectedly");
-                            return crate::EXIT_CODE_SERVER_EXIT_UNEXPECTEDLY.into();
+                            return Err(ShadowsocksError::ServerExitUnexpectedly("server exited unexpectedly".to_owned()));
                         }
                         // Server future resolved with error, which are listener errors in most cases
                         Err(err) => {
-                            eprintln!("server aborted with {err}");
-                            return crate::EXIT_CODE_SERVER_ABORTED.into();
+                            return Err(ShadowsocksError::ServerAborted(format!("server aborted with {err}")));
                         }
                     }
                 }
                 // The abort signal future resolved. Means we should just exit.
                 _ = abort_signal => {
-                    return ExitCode::SUCCESS;
+                    return Ok(());
                 }
                 _ = reload_task => {
                     // continue.
@@ -1059,9 +1041,12 @@ pub fn create(matches: &ArgMatches) -> Result<(Runtime, impl Future<Output = Exi
 /// Program entrance `main`
 #[inline]
 pub fn main(matches: &ArgMatches) -> ExitCode {
-    match create(matches) {
-        Ok((runtime, main_fut)) => runtime.block_on(main_fut),
-        Err(code) => code,
+    match create(matches).and_then(|(runtime, main_fut)| runtime.block_on(main_fut)) {
+        Ok(()) => ExitCode::SUCCESS,
+        Err(err) => {
+            eprintln!("{err}");
+            err.exit_code().into()
+        }
     }
 }
 
@@ -1117,7 +1102,7 @@ impl ServerReloader {
     #[cfg(unix)]
     async fn launch_signal_reload_server_task(self: Arc<Self>) {
         use log::debug;
-        use tokio::signal::unix::{signal, SignalKind};
+        use tokio::signal::unix::{SignalKind, signal};
 
         let mut sigusr1 = signal(SignalKind::user_defined1()).expect("signal");
 
